@@ -102,13 +102,19 @@ class VersionConfig:
         Returns:
             A list of targets matching the criteria.
         """
-        if isinstance(category, str):
-            category = [category]
+        # Prepare categories for filtering
+        match category:
+            case str():
+                categories: list[str] | None = [category]
+            case Iterable():
+                categories = list(category)
+            case None:
+                categories = None
 
         filtered_targets = [
             t
             for t in self.targets
-            if (category is None or t.data.category in category) and (name is None or re.search(name, t.data.name))
+            if (categories is None or t.data.category in categories) and (name is None or re.search(name, t.data.name))
         ]
 
         if inverse:
@@ -426,9 +432,10 @@ class VersionConfig:
 
         It has fallback to the review date and last date of the pentest ongoing.
         """
-        return self.filter_dates(
-            type=[DateType.report_sent, DateType.review, DateType.pentest_ongoing], last_date=True
-        )
+        if (report_sent := self.filter_dates(type=DateType.report_sent, last_date=True)) is not None:
+            return report_sent
+        else:
+            return self.filter_dates(type=[DateType.review, DateType.pentest_ongoing], last_date=True)
 
     @property
     def total_open_risks(self) -> NonNegativeInt:
@@ -438,6 +445,8 @@ class VersionConfig:
     @property
     def sum_risks(self) -> Risks:
         """Get the sum of risks across all targets."""
+        if not self.targets:
+            return Risks()
         return reduce(operator.add, (t.findings.risks for t in self.targets))
 
     @property
